Check that an experience dataset contains the required columns with the expected classes, and validate the classes of optional columns when present.
Value
Invisibly returns the result of .check_col_spec().
Required columns
These columns must be present:
cym: Calendar year-month (Date)uym: Underwriting year-month (Date)loss: Incurred loss amount (numeric)rp: Risk premium (numeric)
Optional columns
These columns are validated only when present:
elap_m: Elapsed month (integer)pd_tp_cd,pd_tp_nm,pd_cd,pd_nm: Product type/product codes and names (character)cv_tp_cd,cv_tp_nm,cv_cd,cv_nm: Coverage type/coverage codes and names (character)rd_tp_cd,rd_tp_nm,rd_cd,rd_nm: Rider type/rider codes and names (character)age_band: Age band (ordered)gender: Gender (factor)ch_cd,ch_nm: Channel code and name (character)n_policy: Number of unique policies in the cell (integer)
Derived columns
The following columns may be derived later by
add_experience_period() and are not validated here:
uy,uyh,uyq: Underwriting year, half-year, quartercy,cyh,cyq: Calendar year, half-year, quarterelap_y,elap_h,elap_q: Elapsed year, half-year, quarter