Returns the factor-level EDSummary carried by the fit, i.e. one row
per development link with fitted intensity g, standard error, and
diagnostic statistics.
Usage
# S3 method for class 'EDFit'
summary(object, ...)Returns the factor-level EDSummary carried by the fit, i.e. one row
per development link with fitted intensity g, standard error, and
diagnostic statistics.
# S3 method for class 'EDFit'
summary(object, ...)